/* Copyright 2020 Purdea Andrei
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

#include "quantum.h"

/* This is a shortcut to help you visually see your layout.
 *
 * The first section contains all of the arguments representing the physical
 * layout of the board and position of the keys.
 *
 * The second converts the arguments into a two-dimensional array which
 * represents the switch matrix.
 */

#define LAYOUT_all( \
    k_esc,   f_1,f_2,f_3,f_4,f_5,f_6,f_7,f_8,f_9,f_10,f_11,f_12,                                             k_prsc,k_scr,  k_paus,  \
    k_tilde, k_1, k_2, k_3, k_4, k_5, k_6, k_7, k_8, k_9, k_0, k_minus, k_equals, k_backspace, k_ext9,       k_ins, k_home, k_pgup,  \
    k_tab,   k_q, k_w, k_e, k_r, k_t, k_y, k_u, k_i, k_o, k_p, k_squarebrop, k_squarebrcl,k_backslash,       k_del, k_end, k_pgdn,   \
    k_caps,   k_a, k_s, k_d, k_f, k_g, k_h, k_j, k_k, k_l, k_semicolon, k_singlequote, k_hashtag, k_return, k_ex1, k_ex2, k_ex3,     \
    k_lshift, k_nonusbs, k_z, k_x, k_c, k_v, k_b, k_n, k_m, k_cm,k_period, k_forwardslash, k_rshift, k_fn,   k_ex4, k_up,  k_ex5,    \
    k_lctrl, k_lgui, k_lalt,         k_space,                     k_extra, k_ralt, k_menu, k_rctrl,           k_left,k_down,k_right \
) \
{ \
    { k_1,      k_tilde,  f_4,   k_3,    k_0,     k_6,   KC_NO,          f_7,         f_11,           k_equals,      k_scr,      k_ins,  KC_NO,  KC_NO   }, \
    { f_1,      k_esc,    f_3,   f_2,    f_6,     f_5,   f_9,            f_8,         f_12,           f_10,          k_paus,     k_prsc, KC_NO,  KC_NO   }, \
    { k_w,      k_tab,    k_r,   k_e,    k_8,     k_y,   k_p,            k_i,         k_backslash,    k_squarebrop,  k_pgdn,     k_del,  KC_NO,  KC_NO   }, \
    { k_2,      KC_NO,    k_5,   k_4,    k_minus, k_7,   k_extra,        k_9,         k_backspace,    KC_NO,         k_pgup,     k_home, KC_NO,  KC_NO   }, \
    { k_s,      k_caps,   k_f,   k_d,    k_j,     k_h,   k_9,            k_k,         k_return,       k_singlequote, KC_NO,      KC_NO,  KC_NO,  KC_NO   }, \
    { k_q,      k_a,      k_g,   KC_NO,  k_u,     k_t,   k_8,            k_o,         KC_NO,          k_squarebrcl,  KC_NO,      k_end,  KC_NO,  KC_NO   }, \
    { KC_NO,    k_lctrl,  k_c,   k_lalt, k_space, k_n,   f_7,            k_ralt,      k_rctrl,        KC_NO,         k_right,    k_left, KC_NO,  KC_NO  }, \
    { k_z,      k_lshift, k_v,   k_x,    k_m,     k_b,   k_forwardslash, k_cm,        k_rshift,       KC_NO,         k_down,     k_up,   KC_NO,  KC_NO   }  \
}

